@@ -152,12 +152,12 @@ class EditingWindow : public QMainWindow
   void handleEnableCategories();
   void updateRecentFileList( const QString &, const QString & );
   void updateRecentFileMenu();
-  void saveAccountsDom();
   void extractAccountAttributes();
   QString decodeXmlEntities( QString );
   void placeNetworkRequest( HttpBusinessType, QByteArray & );
   void setHost( QHttp *, QString &, QString &, bool );
   void setEditActionsEnabled( bool );
+  void purgeBlankAccounts();
 
   int currentAccount, currentBlog, loadedEntryBlog;
   QString loadedAccountId;
@@ -176,7 +176,7 @@ class EditingWindow : public QMainWindow
       allowComments, allowTB, postDateTime, copyTitle, useWordpressAPI,
       allowRegexSearch, useTwoNewlines, 
       useMarkdown, doMarkdownWhenPosting, stripParaTags,
-      enableHighlighting, suppressReadMore;
+      enableHighlighting, suppressReadMore, useUtf8;
   QHash<QString, bool *> accountAttributes;
   QHash<QString, QString *> accountStrings;
   bool entryEverSaved, cleanSave, noAutoSave, noAlphaCats, networkActionsEnabled;
@@ -278,7 +278,6 @@ class EditingWindow : public QMainWindow
   void showHighlightedURL( const QString & );
   void newMTPost(); // formerly blogThis()
   void updatePostCategories();
-  void saveBlogs();
   void setPostCategories();
   void publishPost();
   void setLoadedPostCategories();
@@ -320,6 +319,7 @@ class EditingWindow : public QMainWindow
   void hideProgressBarIfMaximum( int );
   void hideProgressBar();
   void reenableDirty();
+  void saveAccountsDom();
 
  public slots:
   void refreshCategories();
@@ -361,7 +361,7 @@ class EditingWindow : public QMainWindow
   TEXTEDIT *ed;
   QVBoxLayout *mainWindowLayoutWithSearch;
   QHBoxLayout *mainWindowLayout;
-  QPushButton *pbCopyURL;
+  //QPushButton *pbCopyURL;
   QWidget *progressBarContainer;
   QHBoxLayout *progressBarLayout;
   QProgressBar *progressBar;
@@ -369,6 +369,7 @@ class EditingWindow : public QMainWindow
   QMenu *recentFilesMenu;
   QAction *noRecentFilesAction;
   QAction *childCategoryHereAction;
+  QStatusBar *statusWidget;
 
   int previewWindowID;
   int consoleID, edID;
@@ -377,6 +378,7 @@ class EditingWindow : public QMainWindow
   // virtual void resizeEvent( QResizeEvent *e );
   virtual void closeEvent( QCloseEvent * );
   virtual void showEvent( QShowEvent * );
+  virtual void resizeEvent( QResizeEvent * );
   bool eventFilter( QObject *, QEvent * );
 
 signals:
