@@ -29,6 +29,7 @@
 
 #ifdef Q_WS_MAC
 #include <QSystemTrayIcon>
+//#include "macFunctions.h"
 #endif
 
 #include <QMenu>
@@ -200,6 +201,9 @@
     EditingWindow *c = new EditingWindow;
     c->setSTI( this );
     c->setWindowTitle( tr( "QTM - new entry [*]" ) );
+#ifdef Q_WS_MAC
+    //setNoStatusBar( c );
+#endif
     c->show();
     c->activateWindow();
   }
@@ -229,6 +233,9 @@ bool SysTrayIcon::handleArguments()
       qDebug() << "Opening:" << args.at( i );
       if( c->load( args.at( i ), true ) ) {
         c->setSTI( this );
+#ifdef Q_WS_MAC
+	//setNoStatusBar( c );
+#endif
         c->show();
         rv = true;
       }
@@ -360,6 +367,9 @@ void SysTrayIcon::newDoc()
   EditingWindow *c = new EditingWindow;
   c->setSTI( this );
   c->setPostClean();
+#ifdef Q_WS_MAC
+  //setNoStatusBar( c );
+#endif
   c->show();
   c->activateWindow();
   QApplication::alert( c );
@@ -409,6 +419,9 @@ void SysTrayIcon::choose( QString fname )
     } else {
       e->setSTI( this );
       qtm->addRecentFile( e->postTitle(), fn );
+#ifdef Q_WS_MAC
+      //setNoStatusBar( e );
+#endif
       e->show();
       e->activateWindow();
       QApplication::alert( e );
@@ -792,6 +805,9 @@ void SysTrayIcon::doQP( QString receivedText )
     }
   }
 
+#ifdef Q_WS_MAC
+  //setNoStatusBar( c );
+#endif
   c->show();
   c->activateWindow();
 #ifdef Q_WS_WIN
