@@ -19,7 +19,7 @@ EOF
 if [ $2 = "--unity" ]; then
   cat <<EOF
 
-X-Ayatana-Desktop-Shortcuts=NewQTMDocument;OpenQTMDocument;QTMQuickpost
+X-Ayatana-Desktop-Shortcuts=NewQTMDocument;OpenQTMDocument;QTMQuickpost;ReallyQuitQTM
 
 [NewQTMDocument Shortcut Group]
 Name=New Document
@@ -35,7 +35,12 @@ TargetEnvironment=Unity
 Name=Quickpost
 Exec=qtm-quickpost
 TargetEnvironment=Unity
+
+[ReallyQuitQTM Shortcut Group]
+Name=Really quit QTM
+Exec=qdbus uk.co.blogistan.catkin /MainApplication quit
+TargetEnvironment=Unity
+
 EOF
 fi
 
-
